#!/bin/sh

set -e

## some Parameters
PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin
FSTAB="/etc/fstab"
PACKAGE="dphys-setup-drivemount"
COMMENT="dphys-drivemount.sh!do not edit by hand!"
STARTSEQ="## start ${PACKAGE}"
STOPSEQ="## stop ${PACKAGE}"
STORAGE="/storage"
DEBUGLOG="/dev/null"

## clean entries in ${FSTAB}
#  clean between STARTSEQ and STOPSEQ
if /bin/grep "${STARTSEQ}" ${FSTAB} > ${DEBUGLOG}; then
  /bin/sed -e "/${STARTSEQ}/,/${STOPSEQ}/ d" \
       ${FSTAB} > ${FSTAB}.tmp
  mv ${FSTAB}.tmp ${FSTAB}
fi

## delete mountpoints (if not mounted)
for mpoint in ${STORAGE}/*; do
  if [ -d ${mpoint} ]; then
    if ! /bin/grep ${mpoint} /proc/mounts > ${DEBUGLOG}; then
      rm -rf ${mpoint}
    fi
  else 
    rm -f ${mpoint}
  fi
done

## Begin with custom entry in ${FSTAB}

# startmark
echo "${STARTSEQ} ## ${COMMENT}" >> ${FSTAB}

## search the device-file, test if its connected, create mountpoint
## and make it usermountable via fstab
for dirname in `find /dev/discs/*/ -name "disc" -exec dirname {} \;`; do
  for partition in ${dirname}/part*; do
    if ! /bin/grep ${partition} ${FSTAB} > ${DEBUGLOG}; then
      if dd if=${partition} of=/dev/null count=1 >/dev/null 2>&1; then
        mpoint=${STORAGE}/`echo ${partition} | /bin/sed -e "s/.*disc\(.*\)\/part\(.*\)$/disc\1part\2/"`
        if [ ! -d ${mpoint} ]; then
	  mkdir ${mpoint}
	fi
        echo "${partition} ${mpoint} auto noauto,user 0 0" >> ${FSTAB}
      fi
    fi
  done
done

#endmark
echo "${STOPSEQ}" >> ${FSTAB}
